@@ -95,8 +95,7 @@ void Idiot::initialize()
 
 void Idiot::restart( const QList<KCard*> & cards )
 {
-    foreach ( KCard * c, cards )
-    {
+    for (KCard * c : cards) {
         c->setPos( talon->pos() );
         c->setFaceUp( false );
         talon->add( c );
@@ -104,7 +103,7 @@ void Idiot::restart( const QList<KCard*> & cards )
 
     dealRow();
 
-    emit newCardsPossible(true);
+    Q_EMIT newCardsPossible(true);
 }
 
 
@@ -223,7 +222,7 @@ bool Idiot::newCards()
     dealRow();
 
     if ( talon->isEmpty() )
-        emit newCardsPossible( false );
+        Q_EMIT newCardsPossible( false );
 
     return true;
 }
@@ -247,7 +246,7 @@ void Idiot::dealRow()
 void Idiot::setGameState( const QString & state )
 {
     Q_UNUSED( state );
-    emit newCardsPossible( !talon->isEmpty() );
+    Q_EMIT newCardsPossible( !talon->isEmpty() );
 }
 
 
