@@ -107,10 +107,11 @@ MainWindow::MainWindow()
 
     setupActions();
 
-    foreach( const DealerInfo * di, DealerInfoList::self()->games() )
-    {
+    const auto games = DealerInfoList::self()->games();
+    for (const DealerInfo * di : games) {
         m_dealer_map.insert( di->baseId(), di );
-        foreach( int id, di->subtypeIds() )
+        const auto subtypeIds = di->subtypeIds();
+        for (int id : subtypeIds)
             m_dealer_map.insert( id, di );
     }
     m_dealer_it = m_dealer_map.constEnd();
@@ -222,7 +223,7 @@ void MainWindow::setupActions()
     m_hintAction->setToolTip( a->toolTip() );
     m_hintAction->setWhatsThis( a->whatsThis() );
     delete a;
-    QString actionName( KStandardGameAction::name( KStandardGameAction::Hint ) );
+    const QString actionName = QString::fromLatin1(KStandardGameAction::name(KStandardGameAction::Hint));
     actionCollection()->addAction( actionName, m_hintAction );
     connect(m_hintAction, &QAction::triggered, this, &MainWindow::toggleHints);
 
@@ -348,7 +349,7 @@ void MainWindow::helpGame()
         const DealerInfo * di = m_dealer_map.value(m_dealer->gameId());
         QString anchor = QString::fromUtf8( di->untranslatedBaseName() );
         anchor = anchor.toLower();
-        anchor = anchor.remove('\'').replace('&', QLatin1String("and")).replace(' ', '-');
+        anchor = anchor.remove(QLatin1Char('\'')).replace(QLatin1Char('&'), QLatin1String("and")).replace(QLatin1Char(' '), QLatin1Char('-'));
         KHelpClient::invokeHelp(QLatin1String("rules-specific.html#") + anchor);
     }
 }
@@ -532,7 +533,7 @@ void MainWindow::setGameType(int id)
 
     m_gameHelpAction->setText(i18nc("Is disabled and changes to \"Help &with Current Game\" when"
                                   " there is no current game.",
-                                  "Help &with %1", di->baseName().replace('&', QLatin1String("&&"))));
+                                  "Help &with %1", di->baseName().replace(QLatin1Char('&'), QLatin1String("&&"))));
 
     connect(m_dealer, &DealerScene::solverStateChanged, this, &MainWindow::updateSolverDescription);
     connect(m_dealer, &DealerScene::updateMoves, this, &MainWindow::slotUpdateMoves);
@@ -758,7 +759,7 @@ void MainWindow::saveNewToolbarConfig()
 void MainWindow::closeEvent(QCloseEvent *e)
 {
     QString stateDirName = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
-    QString stateFileName = stateDirName + QLatin1Char('/') + saved_state_file ;
+    QString stateFileName = stateDirName + QLatin1String("/" saved_state_file);
     QDir stateFileDir(stateDirName);
     if(!stateFileDir.exists())
     {
@@ -855,20 +856,18 @@ bool MainWindow::loadGame( const QUrl & url, bool addToRecentFiles )
     int gameId = -1;
     bool isLegacyFile;
 
-    if ( xml.name() == "dealer" )
-    {
+    if (xml.name() == QLatin1String("dealer")) {
         isLegacyFile = true;
         bool ok;
         int id = xml.attributes().value(QStringLiteral("id")).toString().toInt( &ok );
         if ( ok )
             gameId = id;
     }
-    else if ( xml.name() == "kpat-game" )
-    {
+    else if (xml.name() == QLatin1String("kpat-game")) {
         isLegacyFile = false;
         QStringRef gameType = xml.attributes().value(QStringLiteral("game-type"));
-        foreach ( const DealerInfo * di, DealerInfoList::self()->games() )
-        {
+        const auto games = DealerInfoList::self()->games();
+        for (const DealerInfo * di : games) {
             if ( di->baseIdString() == gameType )
             {
                 gameId = di->baseId();
@@ -1059,7 +1058,8 @@ void MainWindow::generateThemePreview()
     img.fill( Qt::transparent );
     QPainter p( &img );
 
-    foreach ( KCard * c, m_cardDeck->cards() )
+    const auto cards = m_cardDeck->cards();
+    for (KCard * c : cards)
         c->completeAnimation();
 
     m_view->render( &p );
